@@ -5,6 +5,7 @@
  *
  */
 
+#define __KERNEL__
 #include <sys/types.h>
 #include <termios.h>
 #include <stdio.h>
@@ -13,7 +14,6 @@
 #include <string.h>
 #include <pwd.h>
 #include <errno.h>
-#include <limits.h>
 #include <ctype.h>
 #include <time.h>
 #include <sys/ioctl.h>
