@@ -10,8 +10,6 @@
 #include <fcntl.h>
 #include <string.h>
 #include <sys/utsname.h>
-#include <linux/sched.h>
-#include <linux/tty.h>
 #include "ps.h"
 #include "psdata.h"
 
@@ -310,16 +308,6 @@ kmemread(void *buf, unsigned long addr, int size)
     return n;
 }
 
-int tty_kmemread (struct tty_struct *tty)
-{
-    int	tty_device;
-
-    if (tty == NULL)
-	return (-1);
-    kmemread (&tty_device,(unsigned long) &tty->device,4);
-    return (tty_device); 
-}
-
 #ifdef USE_MMAP
 unsigned long
 get_kword(unsigned long addr)
