@@ -7,6 +7,7 @@
  *
  */
 
+#define __KERNEL__
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -20,12 +21,13 @@
 #include <errno.h>
 #include <signal.h>
 #include <sys/time.h>
-#include <sys/resource.h>
 #include <sys/ioctl.h>
 #include <linux/sched.h>
 #include "ps.h"
 #include "psdata.h"
 
+extern int setpriority __P((int __which, int __who, int __prio));
+
 struct task_struct **task_tbl;
 
 #define RCFILE		".toprc"
