@@ -17,7 +17,9 @@
 #include "ps.h"
 #include "psdata.h"
 
-#define	SYS_PATH	"/usr/src/linux/tools/zSystem"
+#ifndef SYSTEM_FILE
+#define	SYSTEM_FILE "/usr/src/linux/tools/zSystem"
+#endif
 
 
 static update_psdb(char *syspath);
@@ -28,6 +30,7 @@ static struct nlist *namelist;
 static int nsym;
 static char *strings;
 static int stringsize;
+static int data_start;
 
 
 /*
@@ -39,16 +42,10 @@ static int stringsize;
 int
 open_sys(char *sysfile, int update)
 {
-
     if (sysfile == NULL || *sysfile == '\0') {
 	if (open_psdb() == -1) {
-#if 0
-	    if (!update)
-		return -1;
-#else
-	    read_nlist(SYS_PATH);
-#endif
-	    sysfile = SYS_PATH;
+	    sysfile = SYSTEM_FILE;
+	    read_nlist(sysfile);
 	} else
 	    sysfile = db_hdr.sys_path;
     } else
@@ -64,7 +61,7 @@ open_sys(char *sysfile, int update)
 static int
 update_psdb(char *syspath)
 {
-    int fd, sysfd;
+    int fd, sysfd, uts_offset;
     struct utsname uts;
 
     if (namelist == NULL)
@@ -102,7 +99,10 @@ update_psdb(char *syspath)
 	perror(syspath);
 	exit(1);
     }
-    lseek(sysfd, k_addr("_system_utsname") + 1024, SEEK_SET);
+
+    uts_offset = k_addr("_system_utsname") - k_addr("_memory_start");
+    uts_offset = data_start + uts_offset;
+    lseek(sysfd, uts_offset, SEEK_SET);
     read(sysfd, (char *) &uts, sizeof(struct utsname));
     close(sysfd);
     strncpy(db_hdr.uts_release, uts.release, sizeof db_hdr.uts_release);
@@ -140,6 +140,10 @@ read_nlist(char *systemfile)
 	fprintf(stderr, "%s has no symbols\n", systemfile);
 	exit(1);
     }
+    if ((data_start = N_DATOFF(hdr)) == 0) {
+        fprintf(stderr, "%s has no data\n", systemfile);
+	exit(1);
+    }
     lseek(fd, N_STROFF(hdr), SEEK_SET);
     read(fd, (char *) &stringsize, sizeof(stringsize));
     symsize = N_STROFF(hdr) - N_SYMOFF(hdr);
@@ -201,8 +205,10 @@ make_fnctbl(void)
     fncs.strings = strings;
     fncs.stringsize = stringsize;
     for (i = 0; i < nsym; ++i) {
-	if ((namelist[i].n_type & ~N_EXT) == N_TEXT && 
-		!strchr(strings + namelist[i].n_un.n_strx, '.')) {
+	if ((namelist[i].n_type & ~N_EXT) == N_TEXT
+		&& !strchr(strings + namelist[i].n_un.n_strx, '.')
+		&& strcmp(strings + namelist[i].n_un.n_strx,
+			 "___gnu_compiled_c") != 0) {
 	    fp->addr = namelist[i].n_value;
 	    fp->name = namelist[i].n_un.n_strx;
 	    ++fp;
